summaryrefslogtreecommitdiffstats
path: root/tdecore/klibloader.h
diff options
context:
space:
mode:
Diffstat (limited to 'tdecore/klibloader.h')
-rw-r--r--tdecore/klibloader.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/tdecore/klibloader.h b/tdecore/klibloader.h
index 9f080b88b..3e8f9ff45 100644
--- a/tdecore/klibloader.h
+++ b/tdecore/klibloader.h
@@ -273,7 +273,7 @@ public:
* ".la" will be appended.
* @param instance a TDEInstance used to get the standard paths
*/
- static TQString findLibrary( const char * name, const TDEInstance * instance = KGlobal::instance() );
+ static TQString findLibrary( const char * name, const TDEInstance * instance = TDEGlobal::instance() );
protected:
KLibLoader( TQObject* parent = 0, const char* name = 0 );
@@ -311,7 +311,7 @@ private:
* \code
* s_global = new TDEInstance( "kspread" );
* \endcode
* This TDEInstance is comparable to KGlobal used by normal applications.
* It allows you to find resource files (images, XML, sound etc.) belonging
* to the library.
*
@@ -311,7 +311,7 @@ private:
* s_global = new TDEInstance( "kspread" );
* \endcode
- * This TDEInstance is comparable to KGlobal used by normal applications.
+ * This TDEInstance is comparable to TDEGlobal used by normal applications.
* It allows you to find resource files (images, XML, sound etc.) belonging
* to the library.